==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkImageSincInterpolator.java <==
// java wrapper for vtkImageSincInterpolator object
//

package vtk;
import vtk.*;

public class vtkImageSincInterpolator extends vtkAbstractImageInterpolator
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWindowFunction_2(int id0);
  public void SetWindowFunction(int id0)
    { SetWindowFunction_2(id0); }

  private native void SetWindowFunctionToLanczos_3();
  public void SetWindowFunctionToLanczos()
    { SetWindowFunctionToLanczos_3(); }

  private native void SetWindowFunctionToKaiser_4();
  public void SetWindowFunctionToKaiser()
    { SetWindowFunctionToKaiser_4(); }

  private native void SetWindowFunctionToCosine_5();
  public void SetWindowFunctionToCosine()
    { SetWindowFunctionToCosine_5(); }

  private native void SetWindowFunctionToHann_6();
  public void SetWindowFunctionToHann()
    { SetWindowFunctionToHann_6(); }

  private native void SetWindowFunctionToHamming_7();
  public void SetWindowFunctionToHamming()
    { SetWindowFunctionToHamming_7(); }

  private native void SetWindowFunctionToBlackman_8();
  public void SetWindowFunctionToBlackman()
    { SetWindowFunctionToBlackman_8(); }

  private native void SetWindowFunctionToBlackmanHarris3_9();
  public void SetWindowFunctionToBlackmanHarris3()
    { SetWindowFunctionToBlackmanHarris3_9(); }

  private native void SetWindowFunctionToBlackmanHarris4_10();
  public void SetWindowFunctionToBlackmanHarris4()
    { SetWindowFunctionToBlackmanHarris4_10(); }

  private native void SetWindowFunctionToNuttall_11();
  public void SetWindowFunctionToNuttall()
    { SetWindowFunctionToNuttall_11(); }

  private native void SetWindowFunctionToBlackmanNuttall3_12();
  public void SetWindowFunctionToBlackmanNuttall3()
    { SetWindowFunctionToBlackmanNuttall3_12(); }

  private native void SetWindowFunctionToBlackmanNuttall4_13();
  public void SetWindowFunctionToBlackmanNuttall4()
    { SetWindowFunctionToBlackmanNuttall4_13(); }

  private native int GetWindowFunction_14();
  public int GetWindowFunction()
    { return GetWindowFunction_14(); }

  private native String GetWindowFunctionAsString_15();
  public String GetWindowFunctionAsString()
    { return GetWindowFunctionAsString_15(); }

  private native void SetWindowHalfWidth_16(int id0);
  public void SetWindowHalfWidth(int id0)
    { SetWindowHalfWidth_16(id0); }

  private native int GetWindowHalfWidth_17();
  public int GetWindowHalfWidth()
    { return GetWindowHalfWidth_17(); }

  private native void SetUseWindowParameter_18(int id0);
  public void SetUseWindowParameter(int id0)
    { SetUseWindowParameter_18(id0); }

  private native void UseWindowParameterOn_19();
  public void UseWindowParameterOn()
    { UseWindowParameterOn_19(); }

  private native void UseWindowParameterOff_20();
  public void UseWindowParameterOff()
    { UseWindowParameterOff_20(); }

  private native int GetUseWindowParameter_21();
  public int GetUseWindowParameter()
    { return GetUseWindowParameter_21(); }

  private native void SetWindowParameter_22(double id0);
  public void SetWindowParameter(double id0)
    { SetWindowParameter_22(id0); }

  private native double GetWindowParameter_23();
  public double GetWindowParameter()
    { return GetWindowParameter_23(); }

  private native void ComputeSupportSize_24(double id0[],int id1[]);
  public void ComputeSupportSize(double id0[],int id1[])
    { ComputeSupportSize_24(id0,id1); }

  private native void SetBlurFactors_25(double id0,double id1,double id2);
  public void SetBlurFactors(double id0,double id1,double id2)
    { SetBlurFactors_25(id0,id1,id2); }

  private native void SetBlurFactors_26(double id0[]);
  public void SetBlurFactors(double id0[])
    { SetBlurFactors_26(id0); }

  private native void GetBlurFactors_27(double id0[]);
  public void GetBlurFactors(double id0[])
    { GetBlurFactors_27(id0); }

  private native double[] GetBlurFactors_28();
  public double[] GetBlurFactors()
    { return GetBlurFactors_28(); }

  private native void SetAntialiasing_29(int id0);
  public void SetAntialiasing(int id0)
    { SetAntialiasing_29(id0); }

  private native void AntialiasingOn_30();
  public void AntialiasingOn()
    { AntialiasingOn_30(); }

  private native void AntialiasingOff_31();
  public void AntialiasingOff()
    { AntialiasingOff_31(); }

  private native int GetAntialiasing_32();
  public int GetAntialiasing()
    { return GetAntialiasing_32(); }

  private native void SetRenormalization_33(int id0);
  public void SetRenormalization(int id0)
    { SetRenormalization_33(id0); }

  private native void RenormalizationOn_34();
  public void RenormalizationOn()
    { RenormalizationOn_34(); }

  private native void RenormalizationOff_35();
  public void RenormalizationOff()
    { RenormalizationOff_35(); }

  private native int GetRenormalization_36();
  public int GetRenormalization()
    { return GetRenormalization_36(); }

  private native boolean IsSeparable_37();
  public boolean IsSeparable()
    { return IsSeparable_37(); }

  public vtkImageSincInterpolator() { super(); }

  public vtkImageSincInterpolator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-armv7h.pkg.tar.xz: vtk/vtkImageSincInterpolator.java <==
// java wrapper for vtkImageSincInterpolator object
//

package vtk;
import vtk.*;

public class vtkImageSincInterpolator extends vtkAbstractImageInterpolator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWindowFunction_2(int id0);
  public void SetWindowFunction(int id0)
    { SetWindowFunction_2(id0); }

  private native void SetWindowFunctionToLanczos_3();
  public void SetWindowFunctionToLanczos()
    { SetWindowFunctionToLanczos_3(); }

  private native void SetWindowFunctionToKaiser_4();
  public void SetWindowFunctionToKaiser()
    { SetWindowFunctionToKaiser_4(); }

  private native void SetWindowFunctionToCosine_5();
  public void SetWindowFunctionToCosine()
    { SetWindowFunctionToCosine_5(); }

  private native void SetWindowFunctionToHann_6();
  public void SetWindowFunctionToHann()
    { SetWindowFunctionToHann_6(); }

  private native void SetWindowFunctionToHamming_7();
  public void SetWindowFunctionToHamming()
    { SetWindowFunctionToHamming_7(); }

  private native void SetWindowFunctionToBlackman_8();
  public void SetWindowFunctionToBlackman()
    { SetWindowFunctionToBlackman_8(); }

  private native void SetWindowFunctionToBlackmanHarris3_9();
  public void SetWindowFunctionToBlackmanHarris3()
    { SetWindowFunctionToBlackmanHarris3_9(); }

  private native void SetWindowFunctionToBlackmanHarris4_10();
  public void SetWindowFunctionToBlackmanHarris4()
    { SetWindowFunctionToBlackmanHarris4_10(); }

  private native void SetWindowFunctionToNuttall_11();
  public void SetWindowFunctionToNuttall()
    { SetWindowFunctionToNuttall_11(); }

  private native void SetWindowFunctionToBlackmanNuttall3_12();
  public void SetWindowFunctionToBlackmanNuttall3()
    { SetWindowFunctionToBlackmanNuttall3_12(); }

  private native void SetWindowFunctionToBlackmanNuttall4_13();
  public void SetWindowFunctionToBlackmanNuttall4()
    { SetWindowFunctionToBlackmanNuttall4_13(); }

  private native int GetWindowFunction_14();
  public int GetWindowFunction()
    { return GetWindowFunction_14(); }

  private native String GetWindowFunctionAsString_15();
  public String GetWindowFunctionAsString()
    { return GetWindowFunctionAsString_15(); }

  private native void SetWindowHalfWidth_16(int id0);
  public void SetWindowHalfWidth(int id0)
    { SetWindowHalfWidth_16(id0); }

  private native int GetWindowHalfWidth_17();
  public int GetWindowHalfWidth()
    { return GetWindowHalfWidth_17(); }

  private native void SetUseWindowParameter_18(int id0);
  public void SetUseWindowParameter(int id0)
    { SetUseWindowParameter_18(id0); }

  private native void UseWindowParameterOn_19();
  public void UseWindowParameterOn()
    { UseWindowParameterOn_19(); }

  private native void UseWindowParameterOff_20();
  public void UseWindowParameterOff()
    { UseWindowParameterOff_20(); }

  private native int GetUseWindowParameter_21();
  public int GetUseWindowParameter()
    { return GetUseWindowParameter_21(); }

  private native void SetWindowParameter_22(double id0);
  public void SetWindowParameter(double id0)
    { SetWindowParameter_22(id0); }

  private native double GetWindowParameter_23();
  public double GetWindowParameter()
    { return GetWindowParameter_23(); }

  private native void ComputeSupportSize_24(double id0[],int id1[]);
  public void ComputeSupportSize(double id0[],int id1[])
    { ComputeSupportSize_24(id0,id1); }

  private native void SetBlurFactors_25(double id0,double id1,double id2);
  public void SetBlurFactors(double id0,double id1,double id2)
    { SetBlurFactors_25(id0,id1,id2); }

  private native void SetBlurFactors_26(double id0[]);
  public void SetBlurFactors(double id0[])
    { SetBlurFactors_26(id0); }

  private native void GetBlurFactors_27(double id0[]);
  public void GetBlurFactors(double id0[])
    { GetBlurFactors_27(id0); }

  private native double[] GetBlurFactors_28();
  public double[] GetBlurFactors()
    { return GetBlurFactors_28(); }

  private native void SetAntialiasing_29(int id0);
  public void SetAntialiasing(int id0)
    { SetAntialiasing_29(id0); }

  private native void AntialiasingOn_30();
  public void AntialiasingOn()
    { AntialiasingOn_30(); }

  private native void AntialiasingOff_31();
  public void AntialiasingOff()
    { AntialiasingOff_31(); }

  private native int GetAntialiasing_32();
  public int GetAntialiasing()
    { return GetAntialiasing_32(); }

  private native void SetRenormalization_33(int id0);
  public void SetRenormalization(int id0)
    { SetRenormalization_33(id0); }

  private native void RenormalizationOn_34();
  public void RenormalizationOn()
    { RenormalizationOn_34(); }

  private native void RenormalizationOff_35();
  public void RenormalizationOff()
    { RenormalizationOff_35(); }

  private native int GetRenormalization_36();
  public int GetRenormalization()
    { return GetRenormalization_36(); }

  private native boolean IsSeparable_37();
  public boolean IsSeparable()
    { return IsSeparable_37(); }

  public vtkImageSincInterpolator() { super(); }

  public vtkImageSincInterpolator(long id) { super(id); }
  public native long   VTKInit();

}
